@@ -1,2 +1,2 @@
-from .cadf_test import CADF_Test
-from .johansen_test import johansen_test
\ No newline at end of file
+from .cadf_test import cadf_test
+from .johansen_test import johansen_test
