@@ -1,36 +1,64 @@
-from .strategy import Strategy
+from .pair_strategy import PairStrategy
 import numpy as np
 import statsmodels.tsa.stattools as ts
 import pandas as pd
 
 
 class BollingerPair(PairStrategy):
+    """
+    Bollinger band strategy on a pair of equities
+
+    Attributes
+    ----------
+    pair: radium.Pair
+    entry_z : float
+        Z-score to enter position at
+    exit_z: float
+        Z-score to exit position at
+    lookback: int
+        Days looked back at on when calculating optimal positions
+    th_positions : np.float[][2]
+        Theoretical optimum positions calculated by strategy
+
+    See Also
+    --------
+    radium.PairStrategy : Parent class
+    """
+
     def __init__(self, pair, entry_z, exit_z, lookback):
         """
-        Bollinger band strategy on a pair of equities
+        Initialises strategy
 
-        Args:
-            pair: Pair to backtest strategy on
-            entry_z: Z-value to buy units
-            exit_z: Z-value to sell units
-            lookback: Number of signals to lookback on when regressing (for spread/hedge ratios)
+        Parameters
+        ----------
+        pair: radium.Pair
+        entry_z : float
+            Z-score to enter position at
+        exit_z : float
+            Z-score to exit position at
+        lookback : int
+            Days to lookback on when calculating optimal positions
         """
+
         super().__init__(pair)
 
         self.entry_z = entry_z
         self.exit_z = exit_z
         self.lookback = lookback
+        self.th_positions = self.calculate_positions()
+
+
+    def calculate_positions(self):
 
-    def positions(self):
         """
-        Calculates optimum positions
+        Calculates optimum positions calculated by strategy
 
-        Returns: Positions as a 2D array
+        Returns
+        -------
+        th_positions : np.float[][2]
         """
 
-        # Get pair spread using ols estimate of hedge ratio w/ lookback
-        hedge_ratios = self.pair.hedge_ols(self.lookback)
-        spread = self.pair.price_spread(hedge_ratios)
+        spread = self.pair.price_spread
 
         # Calculate Z-score
         spread_mean = spread.rolling(self.lookback).mean()
@@ -39,7 +67,7 @@ class BollingerPair(PairStrategy):
 
         # Calculate long and short entry and exit points
         long_entry = spread_z < -self.entry_z
-        long_exit = spread_z > -self.entry_z
+        long_exit = spread_z > -self.exit_z
 
         short_entry = spread_z > self.entry_z
         short_exit = spread_z < self.exit_z
@@ -54,13 +82,17 @@ class BollingerPair(PairStrategy):
         units_long[0] = 0
         units_long[long_entry] = 1
         units_long[long_exit] = 0
-        units_long = pd.DataFrame(data=units_long, index=self.pair.equity1.data.index, columns=["Units Long"])
+        units_long = pd.DataFrame(data=units_long,
+                                  index=self.pair.equity1.data.index,
+                                  columns=["Units Long"])
         units_long.fillna(method='ffill', inplace=True)
 
         units_short[0] = 0
         units_short[short_entry] = -1
         units_short[short_exit] = 0
-        units_short = pd.DataFrame(data=units_short, index=self.pair.equity1.data.index, columns=["Units Short"])
+        units_short = pd.DataFrame(data=units_short,
+                                   index=self.pair.equity1.data.index,
+                                   columns=["Units Short"])
         units_short.fillna(method='ffill', inplace=True)
 
         units = units_short.values + units_long.values
@@ -68,11 +100,5 @@ class BollingerPair(PairStrategy):
         # Convert units into a n * 2 matrix (due to pair of equities)
         units = np.tile(units, [1, 2])
 
-        # Get hedges and format as a matrix of 1s and -h for share allocation
-        hedge_ratio = self.pair.hedge_ols(self.lookback)
-        share_allocation = ts.add_constant(-hedge_ratio)
-
         # Optimal share positions determined by the Bollinger Bands strategy
-        optimal_positions = units * share_allocation
-
-        return optimal_positions
+        return units * self.pair.hedge_ratios
